@@ -127,6 +127,15 @@ class Library(object):
 
     def message(self, message_spec):
 
+        to_return = message_spec
+
+        if inspect.isclass(message_spec) and\
+                issubclass(message_spec, MessageSpec):
+            message_spec = message_spec()
+
+        if not isinstance(message_spec, MessageSpec):
+            raise TypeError('Message spec must be an instance or a subclass of MessageSpec')
+
         # register in flat registry
         if message_spec.id in self._registered_message_id_set:
             raise ValueError("Message spec already registered for message '%s'" %
@@ -153,7 +162,7 @@ class Library(object):
         if self._is_index_built:
             self.rebuild_index()
 
-        return message_spec
+        return to_return
 
     def message_by_form(self, message_id=None, message_id_list=None,
             base_spec=MessageSpec, **attrs):
@@ -245,7 +254,6 @@ class Library(object):
                 message_id=message_id, **options)
 
     def rebuild_index(self):
-
         self._init_index_containers()
 
         # Build index for handlers
@@ -515,7 +523,7 @@ class Library(object):
         for group_id in group_path:
             cur_level = cur_level.get(group_id, None)
             if not cur_level:
-                raise GroupPathEmptyError(group_path)
+                return []
         return map(attrgetter('id'), cur_level.itervalues())
 
     def _init_containers(self):
